@@ -23,7 +23,8 @@ NO_PARTITIONING = ['NO', 'FALSE', 'OFF', '0']
 RDB = 'RDB'
 CSV = 'CSV'
 TSV = 'TSV'
-EXCEL = ['XLS', 'XLSX', 'XLSM', 'XLSB', 'ODF', 'ODS', 'ODT']
+EXCEL = ['XLS', 'XLSX', 'XLSM', 'XLSB']
+ODS = ['ODS', 'FODS']
 PARQUET = 'PARQUET'
 FEATHER = ['FEATHER', 'FEA']
 ORC = 'ORC'
@@ -41,7 +42,7 @@ ORACLE = 'ORACLE'
 POSTGRESQL = 'POSTGRESQL'
 SQLITE = 'SQLITE'
 
-FILE_SOURCE_TYPES = [CSV, TSV, PARQUET, ORC, STATA, SPSS, JSON, XML] + EXCEL + FEATHER + SAS
+FILE_SOURCE_TYPES = [CSV, TSV, PARQUET, ORC, STATA, SPSS, JSON, XML] + EXCEL + FEATHER + SAS + ODS
 DATA_SOURCE_TYPES = [RDB] + FILE_SOURCE_TYPES
 
 # RDF serializations
@@ -146,8 +147,8 @@ QL_XML = f'{QL_NAMESPACE}XPath'
 ##############################################################################
 
 # classes
-RML_STAR_STAR_MAP = f'{RML_NAMESPACE}StarMap'
-RML_NON_ASSERTED_TRIPLES_MAP = f'{RML_NAMESPACE}NonAssertedTriplesMap'
+RML_STAR_STAR_MAP_CLASS = f'{RML_NAMESPACE}StarMap'
+RML_STAR_NON_ASSERTED_TRIPLES_MAP_CLASS = f'{RML_NAMESPACE}NonAssertedTriplesMap'
 
 # properties
 RML_STAR_QUOTED_TRIPLES_MAP = f'{RML_NAMESPACE}quotedTriplesMap'
@@ -175,6 +176,15 @@ XSD_DATETIME = f'{XSD_NAMESPACE}dateTime'
 XSD_STRING = f'{XSD_NAMESPACE}string'
 
 
+##############################################################################
+#############################   XSD DATA TYPES   #############################
+##############################################################################
+
+RDF_NAMESPACE = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#'
+
+RDF_TYPE = f'{RDF_NAMESPACE}type'
+
+
 ##############################################################################
 ##################################   OTHER   #################################
 ##############################################################################
