@@ -8,7 +8,6 @@ __email__ = "arenas.guerrero.julian@outlook.com"
 
 import re
 import os
-import shutil
 import logging
 import rdflib
 import time
@@ -52,8 +51,8 @@ def get_valid_dir_path(dir_path):
     Checks that a directory exists. If the directory does not exist, it creates the directories in the path.
     """
 
-    dir_path = str(dir_path).strip()
-    if not os.path.exists(dir_path):
+    dir_path = dir_path.strip()
+    if dir_path and not os.path.exists(dir_path):
         os.makedirs(dir_path)
 
     return dir_path
@@ -107,19 +106,14 @@ def get_repeated_elements_in_list(input_list):
     return repeated_elems
 
 
-def get_subject_maps(mappings_df):
+def get_mapping_rule(mappings_df, triples_map_id):
     """
-    Retrieves subject maps from mapping rules in the input DataFrame. No repeated subject maps are returned.
+    Retrieves mapping rule from mapping rules in the input DataFrame by its triples map id.
     """
 
-    subject_maps_df = mappings_df[[
-        'id', 'triples_map_id', 'source_name', 'source_type', 'data_source', 'iterator', 'tablename',
-        'query', 'subject_template', 'subject_reference', 'subject_constant', 'subject_termtype']
-    ]
+    mapping_rule = mappings_df[mappings_df['triples_map_id'] == triples_map_id].iloc[0]
 
-    subject_maps_df = subject_maps_df.drop_duplicates()
-
-    return subject_maps_df
+    return mapping_rule
 
 
 def get_references_in_template(template):
@@ -136,12 +130,12 @@ def get_references_in_template(template):
     return references
 
 
-def triples_to_file(triples, config, mapping_partition=''):
+def triples_to_file(triples, config, mapping_group=None):
     """
     Writes triples to file.
     """
 
-    f = open(config.get_output_file_path(mapping_partition), 'a')
+    f = open(config.get_output_file_path(mapping_group), 'a')
     for triple in triples:
         f.write(f'{triple}.\n')
     f.close()
@@ -155,28 +149,24 @@ def remove_non_printable_characters(string):
     return ''.join(char for char in string if char.isprintable())
 
 
-def clean_output_dir(config):
+def remove_output_files(config, mappings_df):
     """
-    Removes all files and directories within output_dir in config depending on clean_output_dir parameter. The output
-    file, if provided in config, is always deleted.
+    Remove the files that will be used to store the final knowledge graph.
     """
 
     output_dir = config.get_output_dir()
-    output_file = config.get_output_file()
-    if output_file:
-        if os.path.exists(os.path.join(output_dir, output_file)):
+    if output_dir:
+        mapping_groups_names = set(mappings_df['mapping_partition'])
+        for mapping_group_name in mapping_groups_names:
+            mapping_group_file_path = config.get_output_file_path(mapping_group_name)
+            if os.path.exists(mapping_group_file_path):
+                # always delete output file, so that generated triples are not appended to it
+                os.remove(mapping_group_file_path)
+    else:
+        output_file = config.get_output_file_path()
+        if os.path.exists(output_file):
             # always delete output file, so that generated triples are not appended to it
-            os.remove(os.path.join(output_dir, output_file))
-
-    if config.clean_output_dir():
-        for obj in os.listdir(output_dir):
-            obj_path = os.path.join(output_dir, obj)
-            if os.path.isdir(obj_path):
-                shutil.rmtree(obj_path)
-            else:
-                os.remove(obj_path)
-
-        logging.debug('Cleaned output directory.')
+            os.remove(output_file)
 
 
 def replace_predicates_in_graph(graph, predicate_to_remove, predicate_to_add):
@@ -198,36 +188,17 @@ def replace_predicates_in_graph(graph, predicate_to_remove, predicate_to_add):
     return graph
 
 
-def get_mapping_rule_from_triples_map_id(mappings, parent_triples_map_id):
-    """
-    Get the parent triples map of the mapping rule with the given id
-    """
-
-    parent_triples_map = mappings[mappings['triples_map_id'] == parent_triples_map_id]
-
-    return parent_triples_map.iloc[0]
-
-
 def get_delta_time(start_time):
     return "{:.3f}".format((time.time() - start_time))
 
 
-def add_references_in_join_condition(mapping_rule, references, parent_references):
-    references_join, parent_references_join = get_references_in_join_condition(mapping_rule)
-
-    references.update(set(references_join))
-    parent_references.update(set(parent_references_join))
-
-    return references, parent_references
-
-
-def get_references_in_join_condition(mapping_rule):
+def get_references_in_join_condition(mapping_rule, join_conditions):
     references = list()
     parent_references = list()
 
     # if join_condition is not null and it is not empty
-    if pd.notna(mapping_rule['object_join_conditions']) and mapping_rule['object_join_conditions']:
-        join_conditions = eval(mapping_rule['object_join_conditions'])
+    if pd.notna(mapping_rule[join_conditions]) and mapping_rule[join_conditions]:
+        join_conditions = eval(mapping_rule[join_conditions])
         for join_condition in join_conditions.values():
             references.append(join_condition['child_value'])
             parent_references.append(join_condition['parent_value'])
@@ -251,12 +222,13 @@ def normalize_oracle_identifier_casing(dataframe, references):
     return dataframe
 
 
-def remove_null_values_from_dataframe(dataframe, config):
+def remove_null_values_from_dataframe(dataframe, config, references):
     # data to str to be able to perform string replacement
     dataframe = dataframe.astype(str)
 
-    dataframe.replace(config.get_na_values(), np.NaN, inplace=True)
-    dataframe.dropna(axis=0, how='any', inplace=True)
+    if config.get_na_values():  # if there is some NULL values to replace
+        dataframe.replace(config.get_na_values(), np.NaN, inplace=True)
+        dataframe.dropna(axis=0, how='any', subset=references, inplace=True)
 
     return dataframe
 
